@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 use App::perlfind;
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 # Specify like this because it's easier. We compute the reverse later (i.e.,
 # it should be easier on the hacker than on the computer).
@@ -12,7 +12,7 @@ our $VERSION = '2.03';
 # perlsyn here, as that's more likely to be the intended meaning.
 our %found_in = (
     perlop => [
-        qw(lt gt le ge eq ne cmp not and or xor s m tr y
+        qw(lt gt le ge eq ne cmp not and or xor
           q qq qr qx qw \l \u \L \U \Q \E)
     ],
     perlsyn => [qw(if else elsif unless while until for foreach)],
@@ -25,28 +25,6 @@ our %found_in = (
           EXTEND CLEAR FIRSTKEY NEXTKEY WRITE PRINT PRINTF READ READLINE GETC
           CLOSE)
     ],
-    perlvar => [
-        qw(_ a b 0 1 2 3 4 5 6 7 8 9 ARG STDIN STDOUT STDERR ARGV ENV PREMATCH
-          MATCH POSTMATCH LAST_PAREN_MATCH LAST_SUBMATCH_RESULT
-          LAST_MATCH_END MULTILINE_MATCHING INPUT_LINE_NUMBER NR
-          INPUT_RECORD_SEPARATOR RS OUTPUT_AUTOFLUSH OUTPUT_FIELD_SEPARATOR
-          OFS OUTPUT_RECORD_SEPARATOR ORS LIST_SEPARATOR SUBSCRIPT_SEPARATOR
-          SUBSEP FORMAT_PAGE_NUMBER FORMAT_LINES_PER_PAGE FORMAT_LINES_LEFT
-          LAST_MATCH_START FORMAT_NAME FORMAT_TOP_NAME
-          FORMAT_LINE_BREAK_CHARACTERS FORMAT_FORMFEED ACCUMULATOR
-          CHILD_ERROR CHILD_ERROR_NATIVE ENCODING OS_ERROR ERRNO
-          EXTENDED_OS_ERROR EVAL_ERROR PROCESS_ID PID REAL_USER_ID UID
-          EFFECTIVE_USER_ID EUID REAL_GROUP_ID GID EFFECTIVE_GROUP_ID EGID
-          PROGRAM_NAME COMPILING DEBUGGING RE_DEBUG_FLAGS RE_TRIE_MAXBUF
-          SYSTEM_FD_MAX INPLACE_EDIT OSNAME OPEN PERLDB
-          LAST_REGEXP_CODE_RESULT EXCEPTIONS_BEING_CAUGHT BASETIME TAINT
-          UNICODE UTF8CACHE UTF8LOCALE PERL_VERSION WARNING WARNING_BITS
-          WIN32_SLOPPY_STAT EXECUTABLE_NAME ARGVOUT INC SIG __DIE__ __WARN__
-          $& $` $' $+ $^N @+ %+ $. $/ $| $\ $" $; $% $= $- @- %- $~ $^ $:
-          $? $! %! $@ $$ $< $> $[ $] $^A $^C $^D $^E $^F $^H $^I $^L
-          $^M $^O $^P $^R $^S $^T $^V $^W $^X %^H @F @_
-          ), '$,', '$(', '$)',
-    ],
     perlrun => [
         qw(HOME LOGDIR PATH PERL5LIB PERL5OPT PERLIO PERLIO_DEBUG PERLLIB
           PERL5DB PERL5DB_THREADED PERL5SHELL PERL_ALLOW_NON_IFS_LSP
@@ -54,11 +32,10 @@ our %found_in = (
           PERL_HASH_SEED PERL_HASH_SEED_DEBUG PERL_ROOT PERL_SIGNALS
           PERL_UNICODE)
     ],
-    perlpod => [
-        qw(head1 head2 head3 head4 over item back cut pod begin
-          end)
+    perlpod => [ map { ($_, "=$_") }
+        qw(head1 head2 head3 head4 over item back cut pod begin end)
     ],
-    perldata => [qw(__FILE__ __LINE__ __PACKAGE__)],
+    perldata => [qw(__DATA__ __END__)],
 
     # We could also list common functions and methods provided by some
     # commonly used modules, like:
@@ -67,7 +44,6 @@ our %found_in = (
           extends with)
     ],
     Error        => [qw(try catch except otherwise finally record)],
-    SelfLoader   => [qw(__DATA__ __END__ DATA)],
     Storable     => [qw(freeze thaw)],
     Carp         => [qw(carp cluck croak confess shortmess longmess)],
     'Test::More' => [
@@ -95,12 +71,13 @@ our %found_in = (
     'PerlIO' =>
       [qw(:bytes :crlf :mmap :perlio :pop :raw :stdio :unix :utf8 :win32)],
 );
+
 App::perlfind->add_trigger(
     'matches.add' => sub {
         my ($class, $word, $matches) = @_;
         while (my ($file, $words) = each our %found_in) {
             for (@$words) {
-                push @$matches, $file if $_ eq $word;
+                push @$matches, $file if $_ eq $$word;
             }
         }
     }
@@ -127,10 +104,8 @@ and built-in Perl concepts. It knows about things like
     elsif
     VERSION
     END
-    OUTPUT_RECORD_SEPARATOR
-    $^R
-    PERL5OPT
     head3
-    __DATA__
+    =head3
+    __WARN__
     :utf8
 
